@@ -3,7 +3,6 @@ from PyQt5.Qt import *
 from PyQt5.uic import *
 from PyQt5.QtCore import *
 from PyQt5.QtWidgets import *
-#from downloader import *
 import sys
 import requests
 import os
@@ -18,6 +17,7 @@ import subprocess
 from pip_install import install,uninstall,find_moudles
 from load_text import *
 
+
 init(autoreset=True)
 
 is_Chinese = False
@@ -25,6 +25,7 @@ Ui_MainWindow,_ = loadUiType('sources/downloader.ui')
 Fast_link,_ = loadUiType('sources/fast_link.ui')
 Python_script,_ = loadUiType('sources/python_script.ui')
 py_inst,_ = loadUiType('sources/py.ui')
+
 class moudle_installer(QtWidgets.QMainWindow,py_inst):
     def __init__(self):
         super(moudle_installer,self).__init__()
@@ -99,13 +100,27 @@ class Fast(QtWidgets.QMainWindow,Fast_link):
 class window(QtWidgets.QMainWindow,Ui_MainWindow):
     signal = pyqtSignal()
     fast_link = pyqtSignal()
-    version = '1.6'
+    version = '1.8.1'
     def __init__(self):
 
 
-        self.log(f'[{time.ctime()}][main/Info] loading')
+
 
         super(window,self).__init__()
+        with open('log/log.log', 'w') as f:
+            f.write('')
+        self.log(f'[{time.ctime()}][main/Info] loading')
+
+        self.user_name = ''
+        while True:
+            self.user_name = input('Your name is:')
+            if self.user_name != '':
+                break
+            else:
+                self.log(f'[{time.ctime()}][main/WARN] user name is Null,please try again',color=Fore.YELLOW)
+
+        self.log(f'[{time.ctime()}][main/INFO] Setting user:{self.user_name}')
+
         self.setupUi(self)
         self.pushButton.clicked.connect(self.download)
         self.te = ''
@@ -136,6 +151,36 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.log(f'[{time.ctime()}][main/Info] timer initlazing sucsess')
         self.log(
             f'[{time.ctime()}][main/Info] backend library:PyQt5 version {PYQT_VERSION_STR} build on Qt {QT_VERSION_STR}')
+        self.pushButton_6.clicked.connect(self.minecraft_pi_init)
+        self.pushButton_7.clicked.connect(self.minecraft_build_client)
+        self.pushButton_4.clicked.connect(self.set_block)
+        self.pushButton_5.clicked.connect(self.set_blocks)
+    def minecraft_pi_init(self):
+        self.textEdit.setText(self.textEdit.toPlainText()+'import mcpi.minecraft as Minecraft'+'\n')
+    def minecraft_build_client(self):
+        self.textEdit.setText(self.textEdit.toPlainText()+'minecraft_client = Minecraft.minecraft.create()'+'\n')
+    def set_block(self):
+        try:
+            self.textEdit.setText(
+                self.textEdit.toPlainText() + f'minecraft_client.setBlock({int(self.lineEdit_4.text())},{int(self.lineEdit_5.text())},{int(self.lineEdit_6.text())},{int(self.lineEdit_13.text())})'+'\n')
+        except BaseException as e:
+            self.log(f'[{time.ctime()}][main/Warn] mcpi coder exception:{e},ignored',Fore.YELLOW)
+
+            result = QtWidgets.QMessageBox.question(self, 'Exception', f'Error:{e}',
+                                                QtWidgets.QMessageBox.Ok)
+
+
+    def set_blocks(self):
+        try:
+            self.textEdit.setText(
+                self.textEdit.toPlainText() + f'minecraft_client.setBlocks({int(self.lineEdit_7.text())},{int(self.lineEdit_8.text())},{int(self.lineEdit_11.text())},{int(self.lineEdit_9.text())},{int(self.lineEdit_10.text())},{int(self.lineEdit_12.text())},{int(self.lineEdit_13.text())})'+'\n')
+        except BaseException as e:
+            self.log(f'[{time.ctime()}][main/Warn] mcpi coder exception:{e},ignored',Fore.YELLOW)
+
+            result = QtWidgets.QMessageBox.question(self, 'Exception', f'Error:{e}',
+                                                QtWidgets.QMessageBox.Ok)
+
+
 
 
     def loadt(self,dic):
@@ -157,12 +202,24 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.groupBox_5.setTitle(dic['groupBox_5'])
         self.groupBox_6.setTitle(dic['groupBox_6'])
         self.pushButton_3.setText(dic['pushButton_3'])
-        self.setWindowTitle(dic['title'])
+        self.setWindowTitle(self.user_name+dic['title'])
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), dic['tab_win.tab'])
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), dic['tab_win.tab_2'])
         self.tabWidget_2.setTabText(self.tabWidget.indexOf(self.tab), dic['tab_win2.tab'])
         self.tabWidget_2.setTabText(self.tabWidget.indexOf(self.tab_2), dic['tab_win2.tab_2'])
         self.checkBox_4.setText(dic['checkBox_4'])
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), dic['tab_win.tab_5'])
+        self.groupBox_7.setTitle(dic['groupBox_7'])
+        self.groupBox_8.setTitle(dic['groupBox_8'])
+        self.label_8.setText(dic['label_8'])
+        self.label_9.setText(dic['label_9'])
+        self.label_10.setText(dic['label_10'])
+        self.label_11.setText(dic['label_11'])
+        self.pushButton_4.setText(dic['pushButton_4'])
+        self.pushButton_5.setText(dic['pushButton_5'])
+        self.pushButton_6.setText(dic['pushButton_6'])
+        self.pushButton_7.setText(dic['pushButton_7'])
+        self.horizontalSlider.setValue(1000)
 
     def fast(self):
         self.log(
@@ -171,7 +228,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
     def log(self,text,color=Fore.RESET):
         print(color+text)
         try:
-            self.wdw += '\n' + text
+            self.wdw += text + '\n'
             self.textBrowser_2.setText(self.wdw)
         except BaseException:
             self.wdw = ''
@@ -182,6 +239,8 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
             self.textBrowser_2.setGeometry(QtCore.QRect(5, 1, 761, 221))
             self.textBrowser_2.setObjectName("textBrowser_2")
             self.textBrowser_2.setText(self.wdw)
+        with open('log/log.log','a') as f:
+            f.write(text+'\n')
 
     def opencmd(self):
         os.system('cmd')
@@ -192,19 +251,31 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
 
     def load(self):
 
+
         a = open('properties/settings.properties')
 
-        dic = eval(a.read())
-        if dic[0]:
+        dicss = a.read()
+        dicss = eval(dicss)
+
+
+        if dicss['no useragent']:
             self.checkBox.toggle()
-        if dic[1]:
+        if dicss['no speed']:
             self.checkBox_2.toggle()
-        if dic[2]:
+        if dicss['no error']:
             self.checkBox_3.toggle()
-        self.lineEdit.setText(dic[3])
-        self.lineEdit_2.setText(dic[4])
+        self.lineEdit.setText(dicss['url'])
+        self.lineEdit_2.setText(dicss['locate'])
+        if dicss['Chinese']:
+            is_Chinese == True
+            self.checkBox_4.toggle()
+
     def closeEvent(self,event):
-        result = QtWidgets.QMessageBox.question(self,'close','Close?',QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
+        if is_Chinese:
+            result = QtWidgets.QMessageBox.question(self,'关闭','是否关闭?',QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
+        else:
+            result = QtWidgets.QMessageBox.question(self, 'close', 'Close?',
+                                                    QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
         if result == QtWidgets.QMessageBox.Yes:
             self.print()
             event.accept()
@@ -212,11 +283,14 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         else:
             event.ignore()
     def write(self):
+        self.timer.stop()
+        self.timer.start(self.horizontalSlider.value())
         if self.checkBox_4.isChecked():
             self.lang = load('zh-cn.lang')
             self.loadt(self.lang)
             is_Chinese == True
 
+
         else:
             self.lang = load('en-us.lang')
             self.loadt(self.lang)
@@ -224,25 +298,25 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
 
 
         a = open('properties/settings.properties','w')
-        dic = [None,None,None,None,None]
-        if self.checkBox.isChecked():
-            dic[0] = True
-        else:
-            dic[0] = False
+        #dic = [None,None,None,None,None,None]
+        dics = {'no useragent':None,
+               'no speed':None,
+               'no error':None,
+               'url':None,
+               'locate':None,
+               'Chinese':None}
 
-        if self.checkBox_2.isChecked():
-            dic[1] = True
-        else:
-            dic[1] = False
+        dics['no useragent'] = self.checkBox.isChecked()
+        dics['no speed'] = self.checkBox_2.isChecked()
+        dics['no error'] = self.checkBox_3.isChecked()
+        dics['url'] = self.lineEdit.text()
+        dics['locate'] = self.lineEdit_2.text()
+        dics['Chinese'] = self.checkBox_4.isChecked()
 
-        if self.checkBox_3.isChecked():
-            dic[2] = True
-        else:
-            dic[2] = False
-        dic[3] = self.lineEdit.text()
-        dic[4] = self.lineEdit_2.text()
 
-        a.write(str(dic))
+
+
+        a.write(str(dics))
 
 
     def download(self):
@@ -362,19 +436,28 @@ class Main:
         self.a = PS()
         self.fast = Fast()
         self.window = window()
-    def connect(self):
+    def connect_windows(self):
         self.a.un.connect(self.a.run_script)
 
+
         self.fast.a.connect(self.a.show)
         self.fast.b.connect(self.d.show)
         self.window.fast_link.connect(self.fast.show)
+    def setimage(self):
+        self.window.setStyleSheet('#MainWindow{background-color:black}')
+        self.window.tabWidget.setStyleSheet('background-color: black')
+        self.fast.setStyleSheet('background-color:black')
+        self.d.setStyleSheet('background-color:black')
+        self.a.setStyleSheet('background-color:black')
+        self.d.lineEdit.setStyleSheet('color:blue')
     def run(self):
         self.window.show()
         sys.exit(self.app.exec_())
 if __name__ == '__main__':
-    mainclass = Main()
-    mainclass.connect()
-    mainclass.run()
+    main = Main()
+    main.connect_windows()
+    main.setimage()
+    main.run()
 
 
 
